@@ -1004,7 +1004,7 @@ do_move (PedDevice** dev)
 
         constraint = constraint_intersect_and_destroy (
                         ped_file_system_get_copy_constraint (fs, *dev),
-                        constraint_from_start_end (*dev, range_start, range_end));
+                        constraint_from_start_end(*dev,range_start,range_end));
         if (!ped_disk_set_partition_geom (disk, part, constraint,
                                           new_geom.start, new_geom.end))
                 goto error_destroy_constraint;
@@ -1192,6 +1192,9 @@ do_print (PedDevice** dev)
         int             has_num_arg = 0;
         int             has_free_arg = 0;
         int             has_all_arg = 0;
+        char*           transport[13] = {"unknown", "scsi", "ide", "dac960",
+                                         "cpqarray", "file", "ataraid", "i2o",
+                                         "ubd", "dasd", "viodasd", "sx8", "dm"};
         char*           peek_word;
         char*           start;
         char*           end;
@@ -1236,9 +1239,9 @@ do_print (PedDevice** dev)
                 PedDevice *current_dev;
 
                 ped_device_probe_all();
-                current_dev = ped_device_get_next (NULL);
+                current_dev = NULL;
 
-                while (current_dev) {
+                while ((current_dev = ped_device_get_next(current_dev))) {
                         do_print (&current_dev);
                         printf ("\n");
                         current_dev = ped_device_get_next (current_dev);
@@ -1251,7 +1254,7 @@ do_print (PedDevice** dev)
         end = ped_unit_format_byte (*dev, (*dev)->length * (*dev)->sector_size
                                           - 1 );
         printf ("\n");
-        /* TODO: insert dev->model and transport here */
+        printf (_("Model: %s (%s)\n"), (*dev)->model, transport[(*dev)->type]);
         printf (_("Disk %s: %s\n"), (*dev)->path, end);
         printf (_("Sector size (logical/physical): %lldB/%lldB\n"),
                         (*dev)->sector_size, (*dev)->phys_sector_size);
